@@ -95,15 +95,17 @@ class MaxSimCuda(CustomKernel):
     if self.k is not None: assert k == self.k
     if self.dim is not None: assert dim == self.dim
 
+    device = A.device
+
 
     if dim == 1:
-      vals = torch.full([l, n], fill_value=float("-inf"), device="cuda:0", dtype=A.dtype)
-      inds = torch.empty([l, n], device="cuda:0", dtype=torch.long)
-      blocks_per_grid = (math.ceil(m/128), math.ceil(n/128), l)
-    elif dim == 2:
-      vals = torch.full([l, m], fill_value=float("-inf"), device="cuda:0", dtype=A.dtype)
-      inds = torch.empty([l, m], device="cuda:0", dtype=torch.long)
+      vals = torch.full([l, n], fill_value=float("-inf"), device=device, dtype=A.dtype)
+      inds = torch.empty([l, n], device=device, dtype=torch.long)
       blocks_per_grid = (math.ceil(n/128), math.ceil(m/128), l)
+    elif dim == 2:
+      vals = torch.full([l, m], fill_value=float("-inf"), device=device, dtype=A.dtype)
+      inds = torch.empty([l, m], device=device, dtype=torch.long)
+      blocks_per_grid = (math.ceil(m/128), math.ceil(n/128), l)
 
     threads_per_block = (256,)
 
@@ -149,15 +151,17 @@ class MaxSimCuda(CustomKernel):
     if self.k is not None: assert k == self.k
     if self.dim is not None: assert dim == self.dim
 
+    device = A.device
+
 
     if dim == 1:
-      vals = torch.full([l, n], fill_value=float("-inf"), device="cuda:0", dtype=A.dtype)
-      inds = torch.empty([l, n], device="cuda:0", dtype=torch.long)
-      blocks_per_grid = (math.ceil(m/128), math.ceil(n/128), l)
-    elif dim == 2:
-      vals = torch.full([l, m], fill_value=float("-inf"), device="cuda:0", dtype=A.dtype)
-      inds = torch.empty([l, m], device="cuda:0", dtype=torch.long)
+      vals = torch.full([l, n], fill_value=float("-inf"), device=device, dtype=A.dtype)
+      inds = torch.empty([l, n], device=device, dtype=torch.long)
       blocks_per_grid = (math.ceil(n/128), math.ceil(m/128), l)
+    elif dim == 2:
+      vals = torch.full([l, m], fill_value=float("-inf"), device=device, dtype=A.dtype)
+      inds = torch.empty([l, m], device=device, dtype=torch.long)
+      blocks_per_grid = (math.ceil(m/128), math.ceil(n/128), l)
 
 
     threads_per_block = (256,)
@@ -205,14 +209,16 @@ class MaxSimCuda(CustomKernel):
     if self.k is not None: assert k == self.k
     if self.dim is not None: assert dim == self.dim
 
+    device = A.device
+
     if dim == 1:
-      vals = torch.full([l, n], fill_value=float("-inf"), device="cuda:0", dtype=A.dtype)
-      inds = torch.empty([l, n], device="cuda:0", dtype=torch.long)
-      blocks_per_grid = (math.ceil(m/128), math.ceil(n/128), l)
-    elif dim == 2:
-      vals = torch.full([l, m], fill_value=float("-inf"), device="cuda:0", dtype=A.dtype)
-      inds = torch.empty([l, m], device="cuda:0", dtype=torch.long)
+      vals = torch.full([l, n], fill_value=float("-inf"), device=device, dtype=A.dtype)
+      inds = torch.empty([l, n], device=device, dtype=torch.long)
       blocks_per_grid = (math.ceil(n/128), math.ceil(m/128), l)
+    elif dim == 2:
+      vals = torch.full([l, m], fill_value=float("-inf"), device=device, dtype=A.dtype)
+      inds = torch.empty([l, m], device=device, dtype=torch.long)
+      blocks_per_grid = (math.ceil(m/128), math.ceil(n/128), l)
 
     threads_per_block = (256,)
     # blocks_per_grid = (l, math.ceil(n/128), math.ceil(m/128))
@@ -259,14 +265,16 @@ class MaxSimCuda(CustomKernel):
     if self.k is not None: assert k == self.k
     if self.dim is not None: assert dim == self.dim
 
+    device = A.device
+
     if dim == 1:
-      vals = torch.full([l, n], fill_value=float("-inf"), device="cuda:0", dtype=A.dtype)
-      inds = torch.empty([l, n], device="cuda:0", dtype=torch.long)
-      blocks_per_grid = (math.ceil(m/128), math.ceil(n/128), l)
-    elif dim == 2:
-      vals = torch.full([l, m], fill_value=float("-inf"), device="cuda:0", dtype=A.dtype)
-      inds = torch.empty([l, m], device="cuda:0", dtype=torch.long)
+      vals = torch.full([l, n], fill_value=float("-inf"), device=device, dtype=A.dtype)
+      inds = torch.empty([l, n], device=device, dtype=torch.long)
       blocks_per_grid = (math.ceil(n/128), math.ceil(m/128), l)
+    elif dim == 2:
+      vals = torch.full([l, m], fill_value=float("-inf"), device=device, dtype=A.dtype)
+      inds = torch.empty([l, m], device=device, dtype=torch.long)
+      blocks_per_grid = (math.ceil(m/128), math.ceil(n/128), l)
 
     threads_per_block = (256,)
     # blocks_per_grid = (l, math.ceil(n/128), math.ceil(m/128))
